@@ -16,7 +16,7 @@ var searchData=
   ['calendarfieldindex_2eidl_13',['CalendarFieldIndex.idl',['../CalendarFieldIndex_8idl.html',1,'']]],
   ['calendaritem_2eidl_14',['CalendarItem.idl',['../CalendarItem_8idl.html',1,'']]],
   ['calendaritem2_2eidl_15',['CalendarItem2.idl',['../CalendarItem2_8idl.html',1,'']]],
-  ['callablestatement_2eidl_16',['CallableStatement.idl',['../sdbc_2CallableStatement_8idl.html',1,'(Global Namespace)'],['../sdb_2CallableStatement_8idl.html',1,'(Global Namespace)']]],
+  ['callablestatement_2eidl_16',['CallableStatement.idl',['../sdb_2CallableStatement_8idl.html',1,'(Global Namespace)'],['../sdbc_2CallableStatement_8idl.html',1,'(Global Namespace)']]],
   ['camerageometry_2eidl_17',['CameraGeometry.idl',['../CameraGeometry_8idl.html',1,'']]],
   ['candlestickcharttype_2eidl_18',['CandleStickChartType.idl',['../CandleStickChartType_8idl.html',1,'']]],
   ['cannotactivatefactoryexception_2eidl_19',['CannotActivateFactoryException.idl',['../CannotActivateFactoryException_8idl.html',1,'']]],
@@ -55,7 +55,7 @@ var searchData=
   ['cellinsertmode_2eidl_52',['CellInsertMode.idl',['../CellInsertMode_8idl.html',1,'']]],
   ['celljustifymethod_2eidl_53',['CellJustifyMethod.idl',['../CellJustifyMethod_8idl.html',1,'']]],
   ['cellorientation_2eidl_54',['CellOrientation.idl',['../CellOrientation_8idl.html',1,'']]],
-  ['cellproperties_2eidl_55',['CellProperties.idl',['../text_2CellProperties_8idl.html',1,'(Global Namespace)'],['../table_2CellProperties_8idl.html',1,'(Global Namespace)']]],
+  ['cellproperties_2eidl_55',['CellProperties.idl',['../table_2CellProperties_8idl.html',1,'(Global Namespace)'],['../text_2CellProperties_8idl.html',1,'(Global Namespace)']]],
   ['cellprotection_2eidl_56',['CellProtection.idl',['../CellProtection_8idl.html',1,'']]],
   ['cellrange_2eidl_57',['CellRange.idl',['../text_2CellRange_8idl.html',1,'(Global Namespace)'],['../table_2CellRange_8idl.html',1,'(Global Namespace)']]],
   ['cellrangeaddress_2eidl_58',['CellRangeAddress.idl',['../CellRangeAddress_8idl.html',1,'']]],
@@ -119,7 +119,7 @@ var searchData=
   ['chartdatarowproperties_2eidl_116',['ChartDataRowProperties.idl',['../ChartDataRowProperties_8idl.html',1,'']]],
   ['chartdatarowsource_2eidl_117',['ChartDataRowSource.idl',['../ChartDataRowSource_8idl.html',1,'']]],
   ['chartdatavalue_2eidl_118',['ChartDataValue.idl',['../ChartDataValue_8idl.html',1,'']]],
-  ['chartdocument_2eidl_119',['ChartDocument.idl',['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
+  ['chartdocument_2eidl_119',['ChartDocument.idl',['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
   ['chartdocumentwrapper_2eidl_120',['ChartDocumentWrapper.idl',['../ChartDocumentWrapper_8idl.html',1,'']]],
   ['charterrorcategory_2eidl_121',['ChartErrorCategory.idl',['../ChartErrorCategory_8idl.html',1,'']]],
   ['charterrorindicatortype_2eidl_122',['ChartErrorIndicatorType.idl',['../ChartErrorIndicatorType_8idl.html',1,'']]],
@@ -171,7 +171,7 @@ var searchData=
   ['colorscaleentrytype_2eidl_168',['ColorScaleEntryType.idl',['../ColorScaleEntryType_8idl.html',1,'']]],
   ['colorspacetype_2eidl_169',['ColorSpaceType.idl',['../ColorSpaceType_8idl.html',1,'']]],
   ['colortable_2eidl_170',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
-  ['column_2eidl_171',['Column.idl',['../sdb_2Column_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Column_8idl.html',1,'(Global Namespace)']]],
+  ['column_2eidl_171',['Column.idl',['../sdbcx_2Column_8idl.html',1,'(Global Namespace)'],['../sdb_2Column_8idl.html',1,'(Global Namespace)']]],
   ['columndescriptor_2eidl_172',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
   ['columndescriptorcontrol_2eidl_173',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
   ['columndescriptorcontrolmodel_2eidl_174',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
@@ -181,8 +181,8 @@ var searchData=
   ['columntype_2eidl_178',['ColumnType.idl',['../ColumnType_8idl.html',1,'']]],
   ['columnvalue_2eidl_179',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
   ['combinedcharacters_2eidl_180',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
-  ['combobox_2eidl_181',['ComboBox.idl',['../control_2ComboBox_8idl.html',1,'(Global Namespace)'],['../component_2ComboBox_8idl.html',1,'(Global Namespace)']]],
-  ['command_2eidl_182',['Command.idl',['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)'],['../awt_2Command_8idl.html',1,'(Global Namespace)']]],
+  ['combobox_2eidl_181',['ComboBox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
+  ['command_2eidl_182',['Command.idl',['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)'],['../animations_2Command_8idl.html',1,'(Global Namespace)']]],
   ['commandabortedexception_2eidl_183',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
   ['commandbutton_2eidl_184',['CommandButton.idl',['../component_2CommandButton_8idl.html',1,'(Global Namespace)'],['../control_2CommandButton_8idl.html',1,'(Global Namespace)']]],
   ['commanddefinition_2eidl_185',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
